class Player:

    def __init__(self, json):
        self.accounts = json["accounts"]
        self.attributes = json["attributes"]
        self.attributes_version = json["attributesVersion"]
        self.available_languages = json["availableLanguages"]
        self.family_name = json["familyName"]
        self.game = json["game"]
        self.given_name = json["givenName"]
        if "handle" in json:
            self.handle = json["handle"]
        self.headshot = json["headshot"]
        if "homeLocation" in json:
            self.home_location = json["homeLocation"]
        self.id = json["id"]
        self.name = json["name"]
        if "nationality" in json:
            self.nationality = json["nationality"]

        if "teams" in json:
            team_list = []
            for team_json in json["teams"]:
                team_list.append(Team(team_json["team"]))
            self.teams = team_list


class Team:

    def __init__(self, json):
        self.abbreviated_name = json["abbreviatedName"]
        self.accounts = json["accounts"]
        self.address_country = json["addressCountry"]
        self.attributes = json["attributes"]
        self.attributes_version = json["attributesVersion"]
        self.available_languages = json["availableLanguages"]
        self.game = json["game"]
        self.handle = json["handle"]
        self.home_location = json["homeLocation"]
        self.icon = json["icon"]
        self.id = json["id"]
        self.logo = json["logo"]
        self.name = json["name"]
        if "owl_division" in json:
            self.owl_division = json["owl_division"]
        if "players" in json:
            player_list = []
            for player_json in json["players"]:
                player_list.append(Player(player_json['player']))

            self.players = player_list
        self.primary_color = json["primaryColor"]
        self.secondary_color = json["secondaryColor"]
        self.secondary_photo = json["secondaryPhoto"]



import requests
from os import path
from .models.entities import Team, Player


class OverwatchApi:

    def __init__(self, base_url="https://api.overwatchleague.com/"):
        self.base_url = base_url

    def construct_url(self, endpoint):
        return path.join(self.base_url, endpoint)

    def get(self, endpoint):
        return requests.get(self.construct_url(endpoint)).json()

    def get_teams(self):
        teams_api_response = self.get("teams")

        teams = []
        for competitor in teams_api_response["competitors"]:
            teams.append(Team(competitor["competitor"]))

        return teams

    def get_players(self):
        players_api_response = self.get("players")

        players = []
        for player in players_api_response["content"]:
            players.append(Player(player))

        return players
